Извършване на оценка на риска с OiRA | OiRA

Теми

# Извършване на оценка на риска с OiRA

## Стартиране на нова сесия

За да стартирате нова оценка на риска, щракнете върху линка „Стартиране на нова сесия“.

## Отваряне на оценка на риска

След като сте започнали оценката, можете да получите достъп до нея по всяко време чрез информационното табло, като щракнете върху заглавието „Моите оценки на риска“. Оттук можете също да стартирате нова оценка на риска.

Информационно табло.

## Навигация в оценка на риска

В процеса на изготвяне на оценката на риска ще получите указания за изпълнение на няколко стъпки. Те са видими в основното меню в лявата част на екрана:

- Подготовка
- Участие
- Идентифициране + Оценка
- План за действие
- Доклад
- Статус

В зависимост от решенията на партньорите на OiRA / разработчиците на инструменти структурата на отделните инструменти може да се различава. В някои инструменти стъпката за идентифициране и оценяване на рисковете включва план за действие. В такъв случай менюто вляво ще има следния вид:

- Подготовка
- Участие
- Оценка
- Доклад
- Статус

## Подготовка

Изпълнението на всяка сесия / инструмент започва със стъпката „Подготовка“. Тук ще определите името на оценката на риска, което по-късно ще ви помогне да направите разграничение между няколко различни оценки, които сте изпълнили с помощта на инструмента.

Линкът „Научете повече за този инструмент…“ ще ви предостави допълнителна информация за избрания инструмент и за участниците в неговото разработване.

След като щракнете върху бутона „Стартиране“, може да ви бъдат зададени допълнителни въпроси в зависимост от инструмента, който използвате. Този подготвителен екран с „въпроси за определяне на профил“ се появява само когато използвате инструменти, които съдържат такава функция.

Тук можете:

- да изберете или пропуснете ситуация(и) в зависимост от това дали те имат или нямат отношение към вашата стопанска дейност. Изберете отговор „да“, когато е уместно;
- да посочите повече от едно бизнес звена, клонове или магазини и т.н. Съответните рискове ще бъдат повторени за всяко посочено звено.

Екранът „Профил“ в рамките на стъпка „Подготовка“

Стъпка „Подготовка“ е много важна, тъй като на този етап инструментът определя прецизно вида на стопанската дейност и рисковете, които имат отношение към вашето дружество. След като щракнете върху бутона „Запазване и продължаване“, преминавате към следващия раздел „Участие“.

Забележка: Много инструменти не съдържат въпроси за определяне на профил, тъй като не използват тази функция за настройване на инструмента. В такива случаи екранът ще бъде пропуснат автоматично.

## Участие

Тази стъпка напомня колко е важно да бъдат ангажирани работниците и предлага различни начини за осигуряване на продуктивното им участие. Тук можете да изтеглите или разпечатате съдържанието на оценката, за да го предоставите на вашите работници / служители. По този начин ще предоставите на работещите възможност да допринесат за изпълнението на задачата за оценка на ситуацията на тяхното работно място.

## Оценка

В рамките на тази стъпка ще идентифицирате опасностите и проблемите, които се отнасят за вашето дружество.

Забележка: В зависимост от това как е конфигуриран инструментът от партньора на OiRA, стъпката „План за действие“ (вж. по-долу) може да бъде интегрирана в този екран. В такъв случай стъпката е озаглавена общо „Оценка“ и елементите, описани под заглавието „План за действие“, ще бъдат включени в етапа на идентифициране и оценяване на всеки риск.

Идентифициране и оценяване

В лявата част на екрана под „Идентифициране + Оценяване“/„Оценка“ са изброени всички теми / модули, включени в инструмента. Разглежданата в момента тема е подчертана.

### Идентифициране

По отношение на всеки риск трябва да прецените дали описанието на желано състояние, е приложимо за вашето дружество. Можете да въведете следните отговори:

- Да: ако отбележите отговор „да“, не са необходими допълнителни действия, тъй като сте направили оценката, че рискът не е налице.
- Не: ако отбележите отговор „не“, е необходимо да предприемете допълнителни действия. Ще получите указание да определите конкретни мерки.
- Без приложение: някои описания на рискове предоставят възможност да изберете отговор „без приложение“, ако съответният риск не се отнася за вашето дружество / предприятие.

Под всяко описание обикновено е дадена допълнителна информация за конкретния риск:

- Информация: кратко описание, в някои случаи придружено с илюстрации, съдържащо повече подробности за риска;
- Ресурси: допълнителна информация за риска, например препратки към законодателни разпоредби и политики. В някои случаи тук ще намерите приложени документи с по-подробна информация.
- Коментари: тук можете да въведете вашите коментари, които ще бъдат включени в доклада в края на оценката.

След като посочите вашия отговор във връзка с описание на риск и го потвърдите, менюто в лявата част на екрана ще бъде актуализирано с цветен символ, обозначаващ дали сте:

- посочили положителен отговор (зелен потвърдителен символ);
- посочили отрицателен отговор (червен знак хикс);
- отложили посочването на отговор (оранжев въпросителен знак).

Срещу въпросите, на които не сте посочили отговор, остава сивият символ.

### Оценяване

В рамките на тази стъпка вие оценявате степента на приоритет на риска, който сте определили.

Оценяване на риск.

Забележка: В някои инструменти за OiRA етапът на оценяване не е показан. Това зависи от конфигурацията на конкретния инструмент за OiRA, направена от националния партньор / разработчик на инструмента за OiRA.

Ако сте посочили, че даден риск е налице (показано с червен знак хикс), ще се отвори разделът за оценка. В зависимост от метода на оценяване, специфичен за всеки риск, ще получите указание:

- да оцените степента на приоритет: висока, средна или ниска;

Определяне на степента на приоритет на риск.

ИЛИ

- да отговорите на няколко въпроса относно честотата, сериозността и вероятността от риска, като степента на приоритет ще бъде определена въз основа на вашите отговори.

Посочване на променливите за определяне на риска.

### Приоритетни рискове, определени от сектора:

Някои рискове са определени като много значими от националния партньор / разработчика на съответния инструмент за OiRA. От вас няма да бъде поискано да оцените „приоритетните рискове“, тъй като тяхната степен на приоритет ще бъде определена автоматично като „висока“.

Приоритетни рискове.

### Допълнителни рискове

След като приключите с въвеждането на отговорите по всички теми за рискове в „Идентифициране + Оценяване“/„Оценка“, ще стигнете до незадължителната тема „Други рискове“. Тук ще видите бутона „Добавете допълнителен риск“, който ви позволява да създадете собствени теми.

Ако във вашето работно място / дружество има рискове, които не са посочени в инструмента, трябва да ги добавите тук. Можете да определите / формулирате тези рискове изцяло по ваша преценка.

Допълнителни рискове.

„Допълнителни рискове“ се определят по сходен начин с рисковете, включени в инструмента за OiRA, но вие трябва да напишете описанието. Въведеният от вас текст следва като минимум да съдържа кратко описание на проблемната ситуация, като е предвидена възможността да въведете и по-подробна информация. Възможно е също да добавите изображение, онагледяващо ситуацията.

Както по отношение на обикновените рискове, трябва да посочите дали има такъв риск. Това ще ви позволи на по-късен етап да отбележите допълнителните рискове като отстранени, след като сте предприели успешни мерки за тяхното отстраняване, като същевременно те ще останат във вашата оценка на риска с цел документиране.

Можете да въведете, колкото искате, допълнителни рискове.

Добавете допълнителен риск.

## План за действие

В рамките на тази стъпка трябва да набележите мерките, които ще предприемете за отстраняване или ограничаване на идентифицираните рискове.

Забележка: Както е посочено по-горе, планът за действие е представен като отделна стъпка в менюто в лявата част на екрана или е включен под всеки идентифициран риск. Във втория случай стъпката в менюто е озаглавена „Оценка“ и включва както описанията на рисковете, така и избор на отговорите.

Кой от двата варианта е включен в инструмента, зависи от решенията на националния партньор на OiRA / разработчика на инструмента.

### Интегриран план за действие

Интегриран план за действие.

Ако отбележите отговор „не“ за даден въпрос, на екрана ще се отвори модулът за план за действие под „Мерки“.

Можете както да направите своя избор от списък с мерки, предложен от системата, така и да посочите определени от вас мерки.

### Отделен план за действие

Когато планът за действие е отделна стъпка, той е достъпен чрез навигационното меню вляво.

Щракнете върху бутона „Създайте план за действие“, за да започнете да изготвяте план.

Когато работите в рамките на стъпката за създаване на план за действие, менюто вляво показва само рисковете, набелязани за предприемане на допълнителни действия, тъй като за останалите рискове е отбелязано, че не са налице.

За всеки риск, за който е посочен отговор „не“ в процеса на оценяване, както и за приоритетните рискове (независимо дали за тях е въведен положителен или отрицателен отговор), ще трябва да определите мерки.

Риск, включен в плана за действие.

Можете да направите своя избор от списък с мерки, предложен от системата, или да определите собствени мерки.

#### Добавете мярка по ваш избор

Добавяне на допълнителна мярка.

Използвайте бутона „Добавяне на мярка“, за да стартирате процеса по определяне на превантивна мярка. Следва:

- да опишете общия подход, който ще бъде възприет за отстраняване или ограничаване на риска;
- по избор да посочите необходимото ниво на експертни знания и/или приложимите изисквания (напр. можете да посочите, че е необходимо специфично обучение или външни експертни знания за осъществяване на мерките за ограничаване на риска);
- да въведете информация кой отговаря за изпълнението;
- да определите бюджет, ако е приложимо;
- по избор да посочите начална и крайна планирана дата за изпълнение на мярката.

Можете да въведете, колкото е необходимо, мерки.

#### Добавете стандартни мерки

В зависимост от конфигурацията на инструмента, извършена от партньора на OiRA / разработчика, за отделните рискове има предварително определени мерки. За да изберете една или няколко предварително определени мерки, щракнете върху бутона „Избор на стандартни мерки“.

Отваря се контекстно меню, в което са показани всички предложени мерки. Щракнете върху бутона „Добавяне“ срещу мерките, които желаете да приложите.

С това предварително определените мерки ще бъдат включени във вашия план за действие. Описанието на мерките не подлежи на редактиране, но можете и трябва да попълните останалите полета (отговорност за изпълнението, бюджет, дати).

Добавяне на стандартни мерки.

Можете да изтриете във всеки момент както стандартните мерки, така и определените от вас мерки.

## Доклад

След като изготвите план за действие, можете да генерирате доклад.

Ако желаете да въведете коментар, който да бъде включен в доклада, въведете текста на коментара и го запазете.

Коментари към доклада.

Тук можете да намерите по-подробна информация за различните доклади и как да ги използвате.

## Статус

Малката кръгова диаграма в менюто вляво показва вашия напредък до момента в работата с инструмента.

Разделът „Статус“ съдържа обобщена информация за броя на рисковете, които сте идентифицирали, във връзка с колко от тях сте предприели мерки и за колко риска / описания все още не сте въвели отговори.

Страница „Статус“.

Когато отворите екрана „Статус“, можете да видите вашия напредък с всеки модул. Това ще ви помогне да се ориентирате за кои дейности все още е необходимо да извършите оценка и за кои идентифицирани рискове да предоставите мерки.

Scroll to top Load toolbar…
Back

## 3-carrying-out-a-risk-assessment.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More